crystal_toolkit.renderables.site module — Crystal Toolkit documentation

# crystal_toolkit.renderables.site module

crystal_toolkit.renderables.site.get_site_scene(self, connected_sites: list[ConnectedSite] = None, connected_sites_not_drawn: list[ConnectedSite] = None, hide_incomplete_edges: bool = False, incomplete_edge_length_scale: float | None = 1.0, connected_sites_colors: list[str] | None = None, connected_sites_not_drawn_colors: list[str] | None = None, origin: list[float] | None = None, draw_polyhedra: bool = True, explicitly_calculate_polyhedra_hull: bool = False, bond_radius: float = 0.1, draw_magmoms: bool = True, magmom_scale: float = 1.0, legend: Legend | None = None) → Scene
  Parameters

    - connected_sites –

    - connected_sites_not_drawn –

    - hide_incomplete_edges –

    - incomplete_edge_length_scale –

    - connected_sites_colors –

    - connected_sites_not_drawn_colors –

    - origin –

    - explicitly_calculate_polyhedra_hull –

    - legend –

  Returns: